@@ -37,7 +37,7 @@ class Reader(api.Reader):
     def __init__(self, format, stream, manifest_data=None):
         super().__init__()
         if manifest_data is not None:
-            self.from_manifest_data_and_stream(manifest_data, format, stream)
+            self.from_manifest_data_and_stream(manifest_data, format, C2paStream(stream))
         else:
             self.from_stream(format, C2paStream(stream))
 
@@ -114,6 +114,10 @@ class Builder(api.Builder):
 
     def add_ingredient_file(self, ingredient, path):
         format = os.path.splitext(path)[1][1:]
+        if "title" not in ingredient:
+            if isinstance(ingredient, str):
+                ingredient = json.loads(ingredient)
+            ingredient["title"] = os.path.basename(path)
         with open(path, "rb") as file:
             return self.add_ingredient(ingredient, format, file)
 
@@ -251,3 +255,11 @@ def sign_ps256(data: bytes, key: bytes) -> bytes:
         hashes.SHA256()
     )
     return signature
+
+def load_settings_file(path: str, format=None):
+    with open(path, "r") as file:
+        if format is None:
+            # determine the format from the file extension
+            format = os.path.splitext(path)[1][1:]
+        settings = file.read()
+    api.load_settings(settings, format)
\ No newline at end of file
