@@ -64,7 +64,9 @@ impl Error {
             | TooManyManifestStores => Self::Manifest { reason: err_str },
             ClaimMissing { label } => Self::ManifestNotFound { reason: err_str },
             AssertionDecoding(_) | ClaimDecoding => Self::Decoding { reason: err_str },
-            AssertionEncoding | XmlWriteError | ClaimEncoding => Self::Encoding { reason: err_str },
+            AssertionEncoding(_) | XmlWriteError | ClaimEncoding => {
+                Self::Encoding { reason: err_str }
+            }
             InvalidCoseSignature { coset_error } => Self::Signature { reason: err_str },
             CoseSignatureAlgorithmNotSupported
             | CoseMissingKey
@@ -96,8 +98,6 @@ impl Error {
             ClaimVerification(_) | InvalidClaim(_) | JumbfParseError(_) => {
                 Self::Verify { reason: err_str }
             }
-            #[cfg(feature = "add_thumbnails")]
-            ImageError => Self::ImageError(err_str),
             _ => Self::Other { reason: err_str },
         }
     }
